@@ -1,5 +1,5 @@
 /* gobby - A GTKmm driven libobby client
- * Copyright (C) 2005 0x539 dev group
+ * Copyright (C) 2005, 2006 0x539 dev group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -23,48 +23,42 @@
 #include <gtkmm/box.h>
 #include <gtkmm/label.h>
 #include <gtkmm/frame.h>
-#include <gtkmm/separator.h>
+#include <gtkmm/statusbar.h>
 #include <obby/user.hpp>
-#include <obby/local_document_info.hpp>
-#include <obby/local_buffer.hpp>
 #include "document.hpp"
+#include "buffer_def.hpp"
 #include "header.hpp"
 #include "folder.hpp"
 
 namespace Gobby
 {
 
-class StatusBar: public Gtk::Frame
+class StatusBar: public Gtk::Statusbar
 {
 public:
 	StatusBar(Header& header, const Folder& folder);
-	virtual ~StatusBar();
 
-	void update_language(Document& document);
-	void update_cursor(Document& document);
-	void update_from_document(Document& document);
+	void update_language(DocWindow& wnd);
+	void update_cursor(DocWindow& wnd);
+	void update_from_document(DocWindow& wnd);
 
 	void update_connection(const Glib::ustring& str);
 
 	// Calls from the window
-	void obby_start(obby::local_buffer& buf);
+	void obby_start(LocalBuffer& buf);
 	void obby_end();
 	void obby_user_join(const obby::user& user);
 	void obby_user_part(const obby::user& user);
-	void obby_document_insert(obby::local_document_info& document);
-	void obby_document_remove(obby::local_document_info& document);
+	void obby_document_insert(LocalDocumentInfo& document);
+	void obby_document_remove(LocalDocumentInfo& document);
 
 	virtual void on_show();
 
 protected:
 	Header& m_header;
 
-	Gtk::HBox m_box;
-	Gtk::Label m_language;
-	Gtk::Label m_connection;
-	Gtk::Label m_position;
-
-	Gtk::VSeparator m_sep;
+	Gtk::Statusbar m_bar_language;
+	Gtk::Statusbar m_bar_position;
 };
 
 }
