@@ -22,60 +22,89 @@
 
 namespace
 {
-	const gchar* GCOLOR_STRING =
+	const gchar* DEFAULT_GCOLOR_STRING =
 		"#f9dad4:#fddfbe:#fdf3be:#f5fdbe:#dcfdbe:#befde2:#bee9fd:"
 		"#becffd:#c7befd:#f2befd:#fdbedd:#f6abab:#fbc759:#fcffba:"
 		"#f4ffee:#bce9b8:#eefdff:#e8ebff:#fdeeff:#dfdfdf";
 
-	void set_default_palette(Gtk::ColorSelection& selection)
+	void set_palette(Gobby::Config::ParentEntry& config_entry,
+	                 Gtk::ColorSelection& selection)
 	{
 		GtkSettings* settings =
 			gtk_widget_get_settings(GTK_WIDGET(selection.gobj()) );
 
+		Glib::ustring palette = config_entry.get_value<Glib::ustring>(
+			"color-palette",
+			DEFAULT_GCOLOR_STRING
+			);
+
 		g_object_set(
 			settings,
 			"gtk-color-palette",
-			GCOLOR_STRING,
+			palette.c_str(),
 			NULL
 		);
 
 		selection.set_has_palette(true);
 	}
+
+	void save_palette(Gobby::Config::ParentEntry& config_entry,
+	                  Gtk::ColorSelection& selection)
+	{
+		GtkSettings* settings =
+			gtk_widget_get_settings(GTK_WIDGET(selection.gobj()) );
+
+		gchar* palette;
+		g_object_get(settings, "gtk-color-palette", &palette, NULL);
+		config_entry.set_value("color-palette", palette);
+		g_free(palette);
+	}
 }
 
-Gobby::ColorSelection::ColorSelection()
- : Gtk::ColorSelection()
+Gobby::ColorSelection::ColorSelection(Config::ParentEntry& config_entry)
+ : Gtk::ColorSelection(),
+   m_config_entry(config_entry)
 {
-	set_default_palette(*this);
+	set_palette(config_entry, *this);
 }
 
 Gobby::ColorSelection::~ColorSelection()
 {
+	save_palette(m_config_entry, *this);
 }
 
-Gobby::ColorSelectionDialog::ColorSelectionDialog()
- : Gtk::ColorSelectionDialog()
+Gobby::ColorSelectionDialog::
+	ColorSelectionDialog(Config::ParentEntry& config_entry)
+ : Gtk::ColorSelectionDialog(),
+   m_config_entry(config_entry)
 {
-	set_default_palette(*get_colorsel() );
+	set_palette(config_entry, *get_colorsel() );
 }
 
-Gobby::ColorSelectionDialog::ColorSelectionDialog(const Glib::ustring& title)
- : Gtk::ColorSelectionDialog(title)
+Gobby::ColorSelectionDialog::
+	ColorSelectionDialog(Config::ParentEntry& config_entry,
+	                     const Glib::ustring& title)
+ : Gtk::ColorSelectionDialog(title),
+   m_config_entry(config_entry)
 {
-	set_default_palette(*get_colorsel() );
+	set_palette(config_entry, *get_colorsel() );
 }
 
 Gobby::ColorSelectionDialog::~ColorSelectionDialog()
 {
+	save_palette(m_config_entry, *get_colorsel() );
 }
 
-Gobby::ColorButton::ColorButton()
- : Gtk::ColorButton()
+Gobby::ColorButton::ColorButton(Config::ParentEntry& config_entry)
+ : Gtk::ColorButton(),
+   m_config_entry(config_entry)
 {
 }
 
-Gobby::ColorButton::ColorButton(const Gdk::Color& color)
- : Gtk::ColorButton(color)
+Gobby::ColorButton::ColorButton(Config::ParentEntry& config_entry,
+                                const Gdk::Color& color)
+ : Gtk::ColorButton(color),
+   m_config_entry(config_entry)
 {
 }
 
@@ -85,7 +114,7 @@ Gobby::ColorButton::~ColorButton()
 
 void Gobby::ColorButton::on_clicked()
 {
-	ColorSelectionDialog dlg;
+	ColorSelectionDialog dlg(m_config_entry);
 	dlg.get_colorsel()->set_current_color(get_color() );
 	dlg.get_colorsel()->set_current_alpha(get_alpha() );
 
