@@ -86,8 +86,9 @@ void Gobby::GotoDialog::on_show()
 	Gobby::DocWindow* window = m_window.get_current_document();
 	if(window != NULL)
 	{
-		Gtk::TextIter cursor = window->get_document().get_buffer()->
-			get_insert()->get_iter();
+    Glib::RefPtr<Gtk::TextBuffer> buffer =
+      Glib::wrap(GTK_TEXT_BUFFER(window->get_document().get_buffer()), true);
+		Gtk::TextIter cursor = buffer->get_insert()->get_iter();
 
 		m_ent_line.set_value(cursor.get_line() + 1);
 		m_ent_line.select_region(0, m_ent_line.get_text().length());
@@ -102,8 +103,9 @@ void Gobby::GotoDialog::on_goto()
 	if(window != NULL)
 	{
 		int value = m_ent_line.get_value_as_int();
-		Gtk::TextIter begin = window->get_document().get_buffer()->
-			get_iter_at_line(value - 1);
+    Glib::RefPtr<Gtk::TextBuffer> buffer =
+      Glib::wrap(GTK_TEXT_BUFFER(window->get_document().get_buffer()), true);
+		Gtk::TextIter begin = buffer->get_iter_at_line(value - 1);
 		window->set_selection(begin, begin);
 	}
 }
