@@ -85,6 +85,8 @@ Gobby::Window::Window(const IconManager& icon_mgr, Config& config):
 		sigc::mem_fun(*this, &Window::on_session_join) );
 	m_header.action_app_session_save->signal_activate().connect(
 		sigc::mem_fun(*this, &Window::on_session_save) );
+	m_header.action_app_session_save_as->signal_activate().connect(
+		sigc::mem_fun(*this, &Window::on_session_save_as) );
 	m_header.action_app_session_quit->signal_activate().connect(
 		sigc::mem_fun(*this, &Window::on_session_quit) );
 	m_header.action_app_quit->signal_activate().connect(
@@ -98,6 +100,8 @@ Gobby::Window::Window(const IconManager& icon_mgr, Config& config):
 		sigc::mem_fun(*this, &Window::on_document_save) );
 	m_header.action_session_document_save_as->signal_activate().connect(
 		sigc::mem_fun(*this, &Window::on_document_save_as) );
+	m_header.action_session_document_save_all->signal_activate().connect(
+		sigc::mem_fun(*this, &Window::on_document_save_all) );
 	m_header.action_session_document_close->signal_activate().connect(
 		sigc::mem_fun(*this, &Window::on_document_close) );
 
@@ -281,7 +285,7 @@ bool Gobby::Window::on_delete_event(GdkEventAny* event)
 	);
 
 	dlg.set_secondary_text(
-		_("Do you want to close Gobby nevertheless?")
+		_("Do you want to close Gobby anyway?")
 	);
 
 	Gtk::Image* img = Gtk::manage(new Gtk::Image(Gtk::Stock::CANCEL,
@@ -444,6 +448,24 @@ void Gobby::Window::on_session_join()
 }
 
 void Gobby::Window::on_session_save()
+{
+	// Call the dialog if we have no previos filename
+	if(m_prev_session.empty()) {
+		on_session_save_as();
+	} else {
+		// Just overwrite if we already were writing there
+		try
+		{
+			m_buffer->serialise(m_prev_session);
+		}
+		catch(std::exception& e)
+		{
+			display_error(e.what() );
+		}
+	}
+}
+
+void Gobby::Window::on_session_save_as()
 {
 	Gtk::CheckButton m_chk_default_ext(
 		_("Use default .obby extension if none is given")
@@ -717,18 +739,8 @@ void Gobby::Window::on_document_save()
 	handle_document_save();
 }
 
-bool Gobby::Window::handle_document_save()
+bool Gobby::Window::handle_document_save_impl(DocWindow* doc)
 {
-	// Get page
-	DocWindow* doc = get_current_document();
-	if(doc == NULL)
-	{
-		throw std::logic_error(
-			"Gobby::Window::on_document_save:\n"
-			"No document opened"
-		);
-	}
-
 	// Is there already a path for this document?
 	std::string path = m_document_settings.get_path(doc->get_info() );
 	if(!path.empty() )
@@ -746,10 +758,26 @@ bool Gobby::Window::handle_document_save()
 	else
 	{
 		// Open save as dialog otherwise
-		return handle_document_save_as();
+		return handle_document_save_as_impl(doc);
 	}
 }
 
+bool Gobby::Window::handle_document_save()
+{
+	// Get page
+	DocWindow* doc = get_current_document();
+
+	if(doc == NULL)
+	{
+		throw std::logic_error(
+			"Gobby::Window::on_document_save:\n"
+			"No document opened"
+		);
+	}
+
+	return handle_document_save_impl(doc);
+}
+
 void Gobby::Window::on_document_save_as()
 {
 	handle_document_save_as();
@@ -767,10 +795,19 @@ bool Gobby::Window::handle_document_save_as()
 		);
 	}
 
+	return handle_document_save_as_impl(doc);
+}
+
+bool Gobby::Window::handle_document_save_as_impl(DocWindow* doc)
+{
+	// Window title
+	obby::format_string str(_("Save document \"%0%\"") );
+	str << doc->get_info().get_title();
+
 	// Setup dialog
 	EncodingFileChooserDialog dlg(
 		*this,
-		_("Save current document"),
+		str.str(),
 		Gtk::FILE_CHOOSER_ACTION_SAVE
 	);
 
@@ -821,6 +858,15 @@ bool Gobby::Window::handle_document_save_as()
 	return false;
 }
 
+void Gobby::Window::on_document_save_all()
+{
+	for(int i = 0; i < m_folder.get_n_pages(); ++i)
+	{
+		Widget* page = m_folder.get_nth_page(i);
+		handle_document_save_impl(static_cast<DocWindow*>(page) );
+	}
+}
+
 void Gobby::Window::on_document_close()
 {
 	// Get current page
@@ -1078,7 +1124,7 @@ void Gobby::Window::on_obby_user_colour(const obby::user& user)
 
 void Gobby::Window::on_obby_user_colour_failed()
 {
-	display_error(_("Colour change failed: Colour already in use") );
+	display_error(_("Color change failed: Color already in use") );
 }
 
 void Gobby::Window::on_obby_document_insert(DocumentInfo& document)
